<?php

$post_id = get_the_ID();
$polis_site_id = get_field('polis_site_id');
$polis_convo_id = get_field('polis_conversation_id');
$postcodes = get_field('polis_post_codes');
$confirmation_statement = get_field('polis_confirmation_statement');
$area_name = get_field('polis_area_name');
$intro = get_field('polis_intro');
$follow_up = get_field('polis_follow_up');
$polis_active = get_field('polis_active_survey');
$off_message = get_field('polis_survey_off_message');

$postcode_array = array_map(function ($item) {
    return array_map(function ($subitem) {
        return preg_replace('/\s+/', '', $subitem); // Remove all spaces
    }, str_getcsv($item));
}, explode("\n", $postcodes));
$postcode_array = call_user_func_array('array_merge', $postcode_array);
$postcode_json = ($postcodes) ? json_encode($postcode_array) : json_encode(false); ?>

<script>

// Define a flag to track if the event has fired
let eventFired = false;

// Register the message event listener
function handleMessage(event) {
    // Check if the event has already fired
    if (eventFired) { 
        return;
    }

    const data = event.data || {};
    if(!event.origin.replace(/^https?:\/\//, "").match(/(^|\.)pol.is$/)) { 
        return; 
    }

    if (data.name === "vote") {

        let contact = {
            'email': window.email,
            'polis_survey_id': '<?php echo $polis_convo_id; ?>',
        }

        fetch('/app/themes/real-theme/functions/hubspot/add_contact.php', {
            method: 'post',
            headers: {
                'Content-type': 'application/json',
            },
            body: JSON.stringify({
                data: contact,
            }),
        })
        .then(response => response.json())
        .then(result => {
            hubspot_add_contact_to_subscription_type(window.email, '10374656');
        });

        // Set the flag to indicate that the event has fired
        eventFired = true;

        // Remove the event listener
        window.removeEventListener("message", handleMessage);
    }
}

window.addEventListener("message", handleMessage);

</script>

<div class="custom-block polis-container" data-stage-num="1">

<?php if($polis_active) { ?>

    <div class="step" data-stage="1">
        <?php if($intro) { 
            echo $intro;
        } ?>
        <form id="custom-polis">
            <div class="personal-inputs">
                <input type="text" name="fname" placeholder="first name" />
                <input type="text" name="lname" placeholder="last name" />
                <input type="email" name="email" placeholder="email address" />
                <input type="text" name="postcode" id="post-code" placeholder="post code" />
            </div>
            
            <?php if($area_name) { ?>
            <div class="confirm-inputs">
                <input type="checkbox" name="confirm_area" id="confirm-area" />
                <label for="confirm-area">I confirm that I live and/or work in <?php echo $area_name; ?>.</label>
            </div>
            <?php } ?>

            <div class="confirm-inputs">
                <input type="checkbox" name="confirm_age" id="confirm-age" />
                <label for="confirm-age">I confirm that I am 18 years of age or over.</label>
            </div>

            <div class="confirm-inputs">
                <input type="checkbox" name="confirm_gdpr" id="confirm-gdpr" />
                <label for="confirm-gdpr">I agree to the use of my contact details by Real Ideas in relation to this survey.</label>
            </div>

            <div class="statement"><?php echo $confirmation_statement; ?></div>

        </form>
    </div>

    <div class="step" data-stage="2">
        <?php echo $follow_up; ?>

        <?php if($polis_convo_id) { 
            // polis conversation using existing conversation ID ?>
            <div class="polis" data-page_id="<?php echo $post_id; ?>" data-site_id="<?php echo $polis_site_id; ?>" data-conversation_id="<?php echo $polis_convo_id; ?>" ></div>
        <?php } ?>

    </div>

    <div class="polis-form-nav">
        <button class="btn polis-nav" id="polis-next" type="button">Next</button>
    </div>

    <?php } else {
        echo $off_message;
    } ?>

</div>



<script>
  
    const postcodes = <?php echo json_encode($postcode_array); ?>;
    const nextButton = document.querySelector('#polis-next ');
    const polisContainer = document.querySelector('.polis-container');

    nextButton.addEventListener('click', function() {

        var next = false;

        const form = polisContainer.querySelector('#custom-polis');
        var formData = new FormData(form);
        const formValues = {};
        formData.forEach((value, key) => {
            formValues[key] = value;
        });

        var title = 'Error';
        var text = 'Something went wrong, please try again.';

        if(!formValues.fname || !formValues.lname || !formValues.email || !formValues.postcode) {
            title = "Missing Fields";
            text = "Please fill out all fields.";

        } else if(!formValues.confirm_area || !formValues.confirm_age || !formValues.confirm_gdpr) {
            title = "Missing Fields";
            text = "Please confirm all fields before continuing.";

        } else {

            if(postcodes == false) {
                next = true;

            } else {
                let postcode = formValues.postcode.replace(/\s/g, "").toLowerCase();
                next = postcodes.some(item => item.toLowerCase() === postcode);
                
                title = "Invalid Postcode";
                text = "The postcode does not qualify for this survey.";       
            }

        }

        if(next == true) {
            const stepOne = polisContainer.querySelector('.step[data-stage="1"]');
            const stepTwo = polisContainer.querySelector('.step[data-stage="2"]');
            stepOne.style.display = 'none';
            stepTwo.style.display = 'block';
            this.style.visibility = 'hidden';

            window.email = formValues.email;

            let contact = {
                'firstname': formValues.fname,
                'lastname': formValues.lname,
                'email': formValues.email,
                'zip': formValues.postcode,
            }

            fetch('/app/themes/real-theme/functions/hubspot/add_contact.php', {
                method: 'post',
                headers: {
                    'Content-type': 'application/json',
                },
                body: JSON.stringify({
                    data: contact,
                }),
            })
            .then(response => response.json())
            .then((result) => {

                const polisDiv = document.querySelector('.polis'); 
                polisDiv.dataset.xid = result.id; 

                // Load the Pol.is script once the fetch request is complete
                const script = document.createElement('script');
                script.src = 'https://pol.is/embed.js';
                script.async = true;
                document.head.appendChild(script);

            });




        } else {
            triggerFormError(title, text);

        }


    });

    function triggerFormError(title, text) {
        Swal.fire({
            title: title,
            text: text,
            icon: 'error',
            confirmButtonText: 'Dismiss',
        });
    }
</script>