<?php 

require($_SERVER['DOCUMENT_ROOT'] . '/wp/wp-load.php');

$expectedApiKey = '86becd3d6b404a52';

// Ensure the request is a POST request
if($_SERVER['REQUEST_METHOD'] === 'POST') {

    // Get the API key from the request header
    $apiKey = $_SERVER['HTTP_X_API_KEY'] ?? '';

    if ($apiKey === $expectedApiKey) {
        // API key is valid

        // Get the JSON data from the request body
        $jsonData = file_get_contents('php://input');
        
        // Check if the data is valid JSON
        $data = json_decode($jsonData, true);
        
        if($data === null) {
            // JSON data is invalid
            http_response_code(400); // Bad Request
            echo json_encode(['error' => 'Invalid JSON data']);

        } else {
            // JSON data is valid, and it's in the $data variable
            // You can now process the data as needed
            // For example, you can access specific fields using $data['key1'] and $data['key2']

            $eventData = array(
                'post_title'    => $data['title'],
                'post_status'   => 'publish',
                'post_type'     => 'event',
                'post_name'     => $data['slug'],
            );

            // check if the event post exists
            $existing_posts = get_posts(array(
                'post_type'         => 'event',
                'posts_per_page'    => -1,
                'meta_query'        => array(
                    array(
                        'key'       => 'eb_event_id',
                        'value'     =>  $data['acf']['eb_event_id'],
                    ),
                ),
            ));
            if($existing_posts && is_array($existing_posts)) {
                $eventData['ID'] = $existing_posts[0]->ID;
            }

            $post_id = wp_insert_post($eventData);

            if(!is_wp_error($post_id)) {

                $acf_fields = $data['acf'];
                foreach($acf_fields as $key => $value) {
                    update_field($key, $value, $post_id);                    
                }
                
            }
            
            // Respond with a success message
            echo json_encode(['message' => 'JSON data received and processed successfully']);
        }




    } else {
        // Invalid API key
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized']);
    }
} else {
    // Not a POST request
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST requests are allowed']);
}